@@ -19,7 +19,7 @@ use alloc::{boxed::Box, vec, vec::Vec, rc::Rc};
 use bootloader::{BootInfo, entry_point};
 use core::panic::PanicInfo;
 use embedded_graphics::{image::Image, prelude::*};
-use libertyos_kernel::{print, println, task::{Task, kbd, simpexec::SimpleExec, exec::Exec}, time::sleep};
+use libertyos_kernel::{print, println, libcore::task::{Task, kbd, simpexec::SimpleExec, exec::Exec}, time::sleep};
 use tinybmp::DynamicBmp;
 use vga::{ colors::{ Color16, TextModeColor }, writers::{ Graphics640x480x16, GraphicsWriter, ScreenCharacter, TextWriter, Text80x25} };
 
@@ -62,7 +62,7 @@ fn kernel_main(bootinfo: &'static BootInfo) -> !
 	let mut executor = Exec::new();
 
 	// Welcome message
-	println!("LIBERTYOS v0.14.1");
+	println!("LIBERTYOS v0.14.2");
 	println!("");
 
 	#[cfg(test)]
